<!---
	csw-split-carousel-generic-rh.cfm

	This 'generic' render handler render handler implements the 'getGenericFieldMappingsArray' function below to describe
	the available field that can be mapped.

	The logic above the function, renders an image with a caption above it, and optionally renders a description
	and link.

	Note that for 'generic' render handlers the mapped data, if any, will always be passed in the following structure:
		Attributes.ElementInfo.ElementData.PropertyValues
	This is an array of one or more items, with a sub-structure named 'values'.
	Values is a structure with members as defined by the getGenericFieldMappingsArray() function.

	This generic render handler assumes these fields:
		- SlideImage - Required
		- SlideText - Optional
		- TextPosition - Optional
		- SlideBackgroundColor - Optional
		- SlideLayout - Optional
		- ImageLocation - Optional
		- LinkURL - Optional
		- LinkStyle - Optional
		- ImageFocalPoint - Optional
		- ImageSize - Optional
		- LinkText - Optional
		- LinkAlign - Optional

	It also assumes these MeataData Fields
		- Options
				showdots
				showarrows
				autoplay
				infiniteloop
				autoheight
		- slideWaitTime - defaults to 3000
		- slideTransitionSpeed - defaults to 1000
		- SlideTransitionEffect - defaults to 'slide', possible values are:
				slide
				fade
				cube
				coverflow
				flip

	Version: [2018-01-03 11:00 am]
--->

<cfscript>
	// Create the Icon Textblock Component
	csWidget = CreateObject('component','csw-split-carousel');

	// load necessary resources
	csWidget.loadResources();

	// exit if all we're doing is detecting required resources
	if( Request.RenderState.RenderMode EQ "getResources" )
		exit;

	if( NOT structKeyExists(attributes,'elementinfo') )
		exit;

	// Load the Properties from the metadata form
	props = csWidget.loadProperties(Attributes.ElementInfo,Variables.Caller);

	// Make sure we have Props data
	if( NOT csWidget.hasProperties(props) )
		exit;

	// Get the element Data and Render the items
	if( StructKeyExists(Attributes.ElementInfo.ElementData, 'PropertyValues') )
		csWidget.getAndRenderItems( Attributes.ElementInfo.ElementData, Attributes.ElementInfo.ElementParams, props );

</cfscript>



<!--- ////////////////////////////////////////////////////////////////////////// --->
<!--- //////////////////   GENERIC RENDER HANDLER FUNCTIONS   ////////////////// --->
<!--- ////////////////////////////////////////////////////////////////////////// --->

<!---
	This is the function that is called by CommonSpot when this render handler is registred,
	allowing the user to map the fields of the source element to this render handler.

	Here we expose a structure to build describing the possible fields. Each fieldMappingArray
	item is a structure with the following fields:
		- FieldName
		- Description
		- Required
--->
<cffunction name="getGenericFieldMappingsArray" returntype="array" access="private" output="no">
	<cfscript>
		var fieldMappingArray = ArrayNew(1);
		var fieldDetailsStruct = StructNew();

		// --------------------------
		// Slide Layout Properties
		// --------------------------

		// Slide Layout
		fieldDetailsStruct = StructNew();
		fieldDetailsStruct.FieldName = 'SlideLayout';
		fieldDetailsStruct.Description = 'The CSS class that determines the column size ratio split between text area and slide.';
		fieldDetailsStruct.Required = 0;
		arrayAppend(fieldMappingArray, fieldDetailsStruct);

		// Slide Background Color
		fieldDetailsStruct = StructNew();
		fieldDetailsStruct.FieldName = 'SlideBackgroundColor';
		fieldDetailsStruct.Description = 'The background color the slide.';
		fieldDetailsStruct.Required = 0;
		arrayAppend(fieldMappingArray, fieldDetailsStruct);

		// --------------------------
		// Slide Image Properties
		// --------------------------

		// Slide Image
		fieldDetailsStruct = StructNew();
		fieldDetailsStruct.FieldName = 'SlideImage';
		fieldDetailsStruct.Description = 'The server relative URL to the image to display as a slide image in the carousel.';
		fieldDetailsStruct.Required = 0;
		arrayAppend(fieldMappingArray, fieldDetailsStruct);

		// Image Location
		fieldDetailsStruct = StructNew();
		fieldDetailsStruct.FieldName = 'ImageLocation';
		fieldDetailsStruct.Description = 'The CSS class that determines location of the image on the slide.';
		fieldDetailsStruct.Required = 0;
		arrayAppend(fieldMappingArray, fieldDetailsStruct);

		// Image Size
		fieldDetailsStruct = StructNew();
		fieldDetailsStruct.FieldName = 'ImageSize';
		fieldDetailsStruct.Description = 'The CSS class that determines how the image is rendered within the area specified';
		fieldDetailsStruct.Required = 0;
		arrayAppend(fieldMappingArray, fieldDetailsStruct);

		// Image Focal Point
		fieldDetailsStruct = StructNew();
		fieldDetailsStruct.FieldName = 'ImageFocalPoint';
		fieldDetailsStruct.Description = 'The CSS class that determines the focal point on the displayed image';
		fieldDetailsStruct.Required = 0;
		arrayAppend(fieldMappingArray, fieldDetailsStruct);

		// --------------------------
		// Slide Text Properties
		// --------------------------

		// Text
		fieldDetailsStruct = StructNew();
		fieldDetailsStruct.FieldName = 'TextStyle';
		fieldDetailsStruct.Description = 'JSON string that describes the appearance of the slide text (alignment, size, color, etc.)';
		fieldDetailsStruct.Required = 0;
		arrayAppend(fieldMappingArray, fieldDetailsStruct);

		// Text Position
		fieldDetailsStruct = StructNew();
		fieldDetailsStruct.FieldName = 'TextPosition';
		fieldDetailsStruct.Description = 'The CSS class to control the position of the textblock.';
		fieldDetailsStruct.Required = 0;
		arrayAppend(fieldMappingArray, fieldDetailsStruct);

		// Slide Text
		fieldDetailsStruct = StructNew();
		fieldDetailsStruct.FieldName = 'SlideText';
		fieldDetailsStruct.Description = 'The text for the slide.';
		fieldDetailsStruct.Required = 0;
		arrayAppend(fieldMappingArray, fieldDetailsStruct);

		// --------------------------
		// Link/Button Properties
		// --------------------------

		// Link URL
		fieldDetailsStruct = StructNew();
		fieldDetailsStruct.FieldName = 'LinkURL';
		fieldDetailsStruct.Description = 'The server relative URL associated with the slide or button.';
		fieldDetailsStruct.Required = 0;
		arrayAppend(fieldMappingArray, fieldDetailsStruct);

		// Link Text
		fieldDetailsStruct = StructNew();
		fieldDetailsStruct.FieldName = 'LinkText';
		fieldDetailsStruct.Description = 'Text to display for link/button.';
		fieldDetailsStruct.Required = 0;
		arrayAppend(fieldMappingArray, fieldDetailsStruct);

		// Button Type
		fieldDetailsStruct = StructNew();
		fieldDetailsStruct.FieldName = 'Button_Type';
		fieldDetailsStruct.Description = 'The style of control to display, either a button or link. Can also include an icon on the left or right.';
		fieldDetailsStruct.Required = 0;
		arrayAppend(fieldMappingArray, fieldDetailsStruct);

		// Button
		fieldDetailsStruct = StructNew();
		fieldDetailsStruct.FieldName = 'Button';
		fieldDetailsStruct.Description = 'JSON string that describes the appearance of the button (alignment, size, color, etc.)';
		fieldDetailsStruct.Required = 0;
		arrayAppend(fieldMappingArray, fieldDetailsStruct);

		// Button Corners
		fieldDetailsStruct = StructNew();
		fieldDetailsStruct.FieldName = 'Button_Corners';
		fieldDetailsStruct.Description = 'Style for button corners';
		fieldDetailsStruct.Required = 0;
		arrayAppend(fieldMappingArray, fieldDetailsStruct);

		// Link
		fieldDetailsStruct = StructNew();
		fieldDetailsStruct.FieldName = 'Link';
		fieldDetailsStruct.Description = 'JSON string that describes the appearance of the link (alignment, size, color, etc.)';
		fieldDetailsStruct.Required = 0;
		arrayAppend(fieldMappingArray, fieldDetailsStruct);

		// Icon
		fieldDetailsStruct = StructNew();
		fieldDetailsStruct.FieldName = 'Icon';
		fieldDetailsStruct.Description = 'The icon that will appear to the left or right of the button or link.';
		fieldDetailsStruct.Required = 0;
		arrayAppend(fieldMappingArray, fieldDetailsStruct);

		return fieldMappingArray;
	</cfscript>
</cffunction>
